/**
 * Main application component.
 * Sets up the main layout using Header, MainContent, and Footer components.
 * Includes routing for different pages.
 */
// import React from 'react'; // No longer needed for JSX transformation
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom'; // Import router components
import { lazy, Suspense } from 'react';
import Header from './components/Header';
import MainContent from './components/MainContent';
import Footer from './components/Footer';
import SEO from './components/SEO';
import Analytics from './components/Analytics';
// import CarouselDemoPage from './pages/CarouselDemoPage'; // Import the demo page
import CasePage from './pages/Page'; // Import the new CasePage component
import './App.css'; // Keep or modify App specific styles if needed

// Lazy load admin components for better performance
const DashboardPage = lazy(() => import('./pages/admin/DashboardPage'));
const AdminLayout = lazy(() => import('./components/admin/AdminLayout'));
const NewCasePage = lazy(() => import('./pages/admin/NewPage'));
const EditCasePage = lazy(() => import('./pages/admin/EditPage'));
const LoginPage = lazy(() => import('./pages/admin/LoginPage'));
const MediaManagerPage = lazy(() => import('./pages/admin/MediaManagerPage'));

import NotFoundPage from './pages/NotFoundPage'; // Import the NotFoundPage
import ErrorBoundary from './components/ErrorBoundary'; // Import the ErrorBoundary
import { ToastProvider } from './contexts/ToastContext'; // Import ToastProvider
import { AuthProvider } from './contexts/AuthContext'; // Import AuthProvider for Firebase authentication

function App() {
  return (
    <Router> {/* Wrap everything in the Router */}
      {/* Wrap the entire app content with AuthProvider for Firebase authentication */}
      <AuthProvider>
        {/* Wrap the entire app content with ToastProvider */}
        <ToastProvider>
          <div className="app-container"> {/* Simple top-level container */}
            <SEO 
              schemaType="LocalBusiness"
            />
            {/* Google Analytics component */}
            <Analytics 
              measurementId="G-5T68SH1TE5" 
              cookieConsentRequired={true}
              debugMode={false}
            />
            <Header />

            {/* Wrap Routes with ErrorBoundary to catch rendering errors */}
            <ErrorBoundary>
              <Routes>
                {/* Public Routes */}
                <Route path="/" element={<MainContent />} /> {/* Main page content */}
                <Route path="/cases/:caseId" element={<CasePage />} /> {/* Route for individual case pages */}

                {/* Admin Routes - Lazy loaded */}
                <Route path="/admin/login" element={
                  <Suspense fallback={<div>Loading...</div>}>
                    <LoginPage />
                  </Suspense>
                } />
                <Route path="/admin" element={
                  <Suspense fallback={<div>Loading admin...</div>}>
                    <AdminLayout />
                  </Suspense>
                }> {/* Protected Admin Section */}
                  <Route index element={
                    <Suspense fallback={<div>Loading dashboard...</div>}>
                      <DashboardPage />
                    </Suspense>
                  } />
                  <Route path="dashboard" element={
                    <Suspense fallback={<div>Loading dashboard...</div>}>
                      <DashboardPage />
                    </Suspense>
                  } />
                  <Route path="cases/new" element={
                    <Suspense fallback={<div>Loading editor...</div>}>
                      <NewCasePage />
                    </Suspense>
                  } />
                  <Route path="cases/edit/:id" element={
                    <Suspense fallback={<div>Loading editor...</div>}>
                      <EditCasePage />
                    </Suspense>
                  } />
                  <Route path="pages/edit/:id" element={
                    <Suspense fallback={<div>Loading editor...</div>}>
                      <EditCasePage />
                    </Suspense>
                  } />
                  <Route path="media" element={
                    <Suspense fallback={<div>Loading media manager...</div>}>
                      <MediaManagerPage />
                    </Suspense>
                  } />
                </Route>

                {/* Catch-all route for 404 - MUST BE LAST */}
                <Route path="*" element={<NotFoundPage />} />
              </Routes>
            </ErrorBoundary>

            <Footer />
          </div>
        </ToastProvider>
      </AuthProvider>
    </Router>
  );
}

export default App;
